
######Correction for effect size#######

# script source:
# https://figshare.com/articles/dataset/Supplement_1_The_R_script_file_used_for_Monte_Carlo_simulations_exploring_bias_among_log_response_ratio_estimators_/3562659?file=5635143

# Load required libraries
library(openxlsx)  # For reading Excel files
library(moments)   # For statistical calculations
library(parallel)  # For parallel processing 

# Read the data from an Excel file
theData <- read.xlsx("C:/Users/myousefi/File.xlsx",
                     sheet = 1, startRow = 1, colNames = TRUE,
                     rowNames = FALSE, detectDates = FALSE,
                     skipEmptyRows = TRUE, skipEmptyCols = TRUE,
                     rows = NULL, cols = NULL, check.names = FALSE,
                     namedRegion = NULL, na.strings = "NA",
                     fillMergedCells = FALSE)

# Display the first few rows of the dataset
head(theData)

# Attach the dataset for easier access to variable names 
attach(theData)

# Explore the structure of the dataset
str(theData)

# Calculate effect size (log response ratio) and its variance
RR <- log(MeanIntercr / Meanctr)
var_RR <- (SDIntercr^2) / (NIntercr * (MeanIntercr^2)) +
  (SDctr^2) / (Nctr * (Meanctr^2))

# Display the calculated effect size and its variance
RR
var_RR

# Create a data frame to store the effect size and variance
effects <- data.frame(X_t = MeanIntercr, sd_t = SDIntercr, N_t = NIntercr,
                      X_c = Meanctr, sd_c = SDctr, N_c = Nctr,
                      RR = RR, var_RR = var_RR)

# Remove rows with missing values
effects <- effects[complete.cases(effects),]

# Calculate mean, variance, and skewness of the effect size
RR_mean <- mean(effects$RR)
RR_var <- var(effects$RR)
RR_skew <- skewness(effects$RR)

# Calculate mean and variance of the effect size variance
var_RR_mean <- mean(effects$var_RR)
var_RR_var <- var(effects$var_RR)

# Calculate corrected effect size (delta-RR) and its variance
delta_RR <- effects$RR + 0.5 * ((effects$sd_t^2) / (effects$N_t * (effects$X_t^2)) -
                                  (effects$sd_c^2) / (effects$N_c * (effects$X_c^2)))
var_delta_RR <- effects$var_RR + 0.5 * ((effects$sd_t^4) / ((effects$N_t^2) * (effects$X_t^4)) +
                                          (effects$sd_c^4) / ((effects$N_c^2) * (effects$X_c^4)))

# Create a data frame to store the corrected effect size and its variance
My_DataFrame <- data.frame(delta_RR, var_delta_RR)

# Write the corrected effect size variances to a text file
write.table(My_DataFrame, file = "variances_BD_Lajeunesse2.txt", sep = "\t",
            row.names = TRUE, col.names = NA)
