
########  meta analysis associated to the different Plant diversity #######

# Load required library
library(openxlsx)
library(metafor)

######################Intercropping  Meta analysis ###################

# Read data from Excel file
intcropping=read.xlsx("D:/ETH/DF2/Pest/for submission/Intercropping dataset.xlsx",
                      sheet = 1, startRow = 1, colNames = TRUE,
                      rowNames = FALSE, detectDates = FALSE, skipEmptyRows = TRUE,
                      skipEmptyCols = TRUE, rows = NULL, cols = NULL, check.names = FALSE,
                      namedRegion = NULL, na.strings = "NA", fillMergedCells = FALSE)

# Convert id column to factor
intcropping$Effect.size.ID<-as.factor(intcropping$Effect.size.ID) 

# Display the first few rows of the intcropping data
head(intcropping) 

# Attach intcropping data
attach(intcropping)

# Print structure of the data
str(intcropping)


############Meta analysis on overall inretcropping dataset

overall<-rma.mv(delta_RR, var_delta, dat=intcropping, method="REML",random=list(~1|Study.ID,~1|Effect.size.ID)) 
summary(overall)

############# Subset for Herbivores, Parasitoids, and Predators #############

Herbivores<- subset(intcropping, intcropping$Functional.groups=="herbivores")
Predator<- subset(intcropping, intcropping$Functional.groups=="predators")
parasitoids<- subset(intcropping, intcropping$Functional.groups=="parasitoids")



############# Meta-Analysis associated to the different Functional level (Herbivores) #############

# No moderator model for Herbivores
nomoderator<-rma.mv(delta_RR, var_delta, dat=Herbivores, method="REML",random=list(~1|Study.ID,~1|Effect.size.ID)) 
summary(nomoderator)

# Main Crop Analysis
# Perform multilevel meta-analysis for Main Crop
Hmaincrop <- rma.mv(delta_RR, var_delta, dat=Herbivores, mods=~Main.crop-1, method="REML", random=list(~1|Study.ID,~1|Effect.size.ID))
# Generate summary of the analysis
summary(Hmaincrop)

# Second Crop Analysis
# Perform multilevel meta-analysis for Second Crop
Hsecond <- rma.mv(delta_RR, var_delta, dat=Herbivores, mods=~Second.crop-1, method="REML", random=list(~1|Study.ID,~1|Effect.size.ID))
# Generate summary of the analysis
summary(Hsecond)

# Irrigation Pattern Analysis
# Perform multilevel meta-analysis for Irrigation Pattern
Hirrigation <- rma.mv(delta_RR, var_delta, dat=Herbivores, mods=~Irrigation.pattern-1, method="REML", random=list(~1|Study.ID,~1|Effect.size.ID))
# Generate summary of the analysis
summary(Hirrigation)

# Levels Analysis
# Perform multilevel meta-analysis for Levels
HLEvels <- rma.mv(delta_RR, var_delta, dat=Herbivores, mods=~Level-1, method="REML", random=list(~1|Study.ID,~1|Effect.size.ID))
# Generate summary of the analysis
summary(HLEvels)

# Subset dataset for Design analysis
designdataset <- subset(Herbivores, Design != "mixed")
View(designdataset)

# Design Analysis
Hdesign <- rma.mv(delta_RR, var_delta, dat=designdataset, mods=~Design-1, method="REML", random=list(~1|Study.ID,~1|Effect.size.ID))
# Generate summary of the analysis
summary(Hdesign)

# Habitat Analysis
HHabitat <- rma.mv(delta_RR, var_delta, dat=Herbivores, mods=~Habitat-1, method="REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(HHabitat)

# Duration of the Study Analysis
# Convert Experimental duration to numeric
Herbivores$`Experimental.duration.(year)` <- as.numeric(Herbivores$`Experimental.duration.(year)`)
# Perform multilevel meta-analysis for Duration of the Study
Hduration <- rma.mv(delta_RR, var_delta, dat=Herbivores, mods=~`Experimental.duration.(year)`, method="REML", random=list(~1|sampling.da,~1|Effect.size.ID))
# Generate summary of the analysis
summary(Hduration)


############# Meta-Analysis associated to the different Functional level (predator) #############

# Overall analysis
preASLI <- rma.mv(delta_RR, var_delta, dat = Predator, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(preASLI)  # Summary of the overall analysis

# Analysis based on Main crop
premaincrop <- rma.mv(delta_RR, var_delta, dat = Predator, mods = ~Main.crop-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(premaincrop)  # Summary of the analysis based on Main crop

# Analysis based on Second crop
presecondcrop <- rma.mv(delta_RR, var_delta, dat = Predator, mods = ~Second.crop-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(presecondcrop)  # Summary of the analysis based on Second crop

# Subset dataset by Design (excluding "mixed" designs)
designdataset2 <- subset(Predator, Design != "mixed")

# Analysis based on Design
Predesign <- rma.mv(delta_RR, var_delta, dat = designdataset2, mods = ~Design-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(Predesign)  # Summary of the analysis based on Design

# Analysis based on Irrigation pattern
preirrigation <- rma.mv(delta_RR, var_delta, dat = Predator, mods = ~Irrigation.pattern-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(preirrigation)  # Summary of the analysis based on Irrigation pattern

# Analysis based on Habitat
prehabitat <- rma.mv(delta_RR, var_delta, dat = Predator, mods = ~Habitat-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(prehabitat)  # Summary of the analysis based on Habitat




######################ASE Meta analysis ###################

# Load ASE data from Excel file
library(openxlsx)
ASE <- read.xlsx("O:/DF2/Pest/AE/AES dataset.xlsx", sheet = 1, startRow = 1, colNames = TRUE,
                 rowNames = FALSE, detectDates = FALSE, skipEmptyRows = TRUE,
                 skipEmptyCols = TRUE, rows = NULL, cols = NULL, check.names = FALSE,
                 namedRegion = NULL, na.strings = "NA", fillMergedCells = FALSE)
# Display the first few rows of the ASE data
head(ASE) 

# Convert id column to factor
ASE$id <- as.factor(ASE$Effect.size.ID)

# Attach ASE data
attach(ASE)

# Check the structure of ASE data
str(ASE)


############Meta analysis on overall AES dataset
overallASE <- rma.mv(delta_RR_AES, var_delta_AES, dat = ASE, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(overallASE)  # Summary of the overall ASE analysis


# Subset ASE data for Herbivores, Parasitoids, and Predators
Herbivores1 <- subset(ASE, ASE$functional.group == "Herbivore")
parasitoids1 <- subset(ASE, ASE$functional.group == "parasitoids")
Predator1 <- subset(ASE, ASE$functional.group == "predators")


############# Meta-Analysis associated to the different Functional level (predator) AES#############

# Null model analysis
nullpredator <- rma.mv(delta_RR_AES, var_delta_AES, dat = Predator1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(nullpredator)

# Analysis based on the main crop
premaincrop <- rma.mv(delta_RR_AES, var_delta_AES, dat = Predator1, mods = ~main.crop-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(premaincrop)

# Analysis based on the type of AES
pretype <- rma.mv(delta_RR_AES, var_delta_AES, dat = Predator1, mods = ~type.of.AES-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(pretype)

# Analysis based on AES width
prewide <- rma.mv(delta_RR_AES, var_delta_AES, dat = Predator1, mods = ~AES.Width-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(prewide)

# Analysis based on habitat
preHabitatt <- rma.mv(delta_RR_AES, var_delta_AES, dat = Predator1, mods = ~Habitat-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(preHabitatt)




############# Meta-Analysis associated to the different Functional level (Herbivore) AES#############


# Analysis based on the main crop
Herbmaincrop <- rma.mv(delta_RR_AES, var_delta_AES, dat = Herbivores1, mods = ~main.crop-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(Herbmaincrop)

# Analysis based on second crop
Herbsecondcrop <- rma.mv(delta_RR_AES, var_delta_AES, dat = Herbivores1, mods = ~AES.Width-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(Herbsecondcrop)


# Analysis based on the type of AES
Herbtype <- rma.mv(delta_RR_AES, var_delta_AES, dat = Herbivores1, mods = ~type.of.AES-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(Herbtype)

# Analysis based on habitat
HerbHabitatt <- rma.mv(delta_RR_AES, var_delta_AES, dat = Herbivores1, mods = ~Habitat-1, method = "REML", random=list(~1|Study.ID,~1|Effect.size.ID))
summary(HerbHabitatt)

